[pypy-commit] pypy py3k: Merge heads

rguillebert noreply at buildbot.pypy.org
Tue Jan 17 12:25:27 CET 2012


Author: Romain Guillebert <romain.py at gmail.com>
Branch: py3k
Changeset: r51394:7948fef3ed5a
Date: 2012-01-17 12:25 +0100
http://bitbucket.org/pypy/pypy/changeset/7948fef3ed5a/

Log:	Merge heads

diff --git a/lib_pypy/binascii.py b/lib_pypy/binascii.py
--- a/lib_pypy/binascii.py
+++ b/lib_pypy/binascii.py
@@ -598,68 +598,68 @@
     return ''.join(result)
 
 crc_32_tab = [
-    0x00000000L, 0x77073096L, 0xee0e612cL, 0x990951baL, 0x076dc419L,
-    0x706af48fL, 0xe963a535L, 0x9e6495a3L, 0x0edb8832L, 0x79dcb8a4L,
-    0xe0d5e91eL, 0x97d2d988L, 0x09b64c2bL, 0x7eb17cbdL, 0xe7b82d07L,
-    0x90bf1d91L, 0x1db71064L, 0x6ab020f2L, 0xf3b97148L, 0x84be41deL,
-    0x1adad47dL, 0x6ddde4ebL, 0xf4d4b551L, 0x83d385c7L, 0x136c9856L,
-    0x646ba8c0L, 0xfd62f97aL, 0x8a65c9ecL, 0x14015c4fL, 0x63066cd9L,
-    0xfa0f3d63L, 0x8d080df5L, 0x3b6e20c8L, 0x4c69105eL, 0xd56041e4L,
-    0xa2677172L, 0x3c03e4d1L, 0x4b04d447L, 0xd20d85fdL, 0xa50ab56bL,
-    0x35b5a8faL, 0x42b2986cL, 0xdbbbc9d6L, 0xacbcf940L, 0x32d86ce3L,
-    0x45df5c75L, 0xdcd60dcfL, 0xabd13d59L, 0x26d930acL, 0x51de003aL,
-    0xc8d75180L, 0xbfd06116L, 0x21b4f4b5L, 0x56b3c423L, 0xcfba9599L,
-    0xb8bda50fL, 0x2802b89eL, 0x5f058808L, 0xc60cd9b2L, 0xb10be924L,
-    0x2f6f7c87L, 0x58684c11L, 0xc1611dabL, 0xb6662d3dL, 0x76dc4190L,
-    0x01db7106L, 0x98d220bcL, 0xefd5102aL, 0x71b18589L, 0x06b6b51fL,
-    0x9fbfe4a5L, 0xe8b8d433L, 0x7807c9a2L, 0x0f00f934L, 0x9609a88eL,
-    0xe10e9818L, 0x7f6a0dbbL, 0x086d3d2dL, 0x91646c97L, 0xe6635c01L,
-    0x6b6b51f4L, 0x1c6c6162L, 0x856530d8L, 0xf262004eL, 0x6c0695edL,
-    0x1b01a57bL, 0x8208f4c1L, 0xf50fc457L, 0x65b0d9c6L, 0x12b7e950L,
-    0x8bbeb8eaL, 0xfcb9887cL, 0x62dd1ddfL, 0x15da2d49L, 0x8cd37cf3L,
-    0xfbd44c65L, 0x4db26158L, 0x3ab551ceL, 0xa3bc0074L, 0xd4bb30e2L,
-    0x4adfa541L, 0x3dd895d7L, 0xa4d1c46dL, 0xd3d6f4fbL, 0x4369e96aL,
-    0x346ed9fcL, 0xad678846L, 0xda60b8d0L, 0x44042d73L, 0x33031de5L,
-    0xaa0a4c5fL, 0xdd0d7cc9L, 0x5005713cL, 0x270241aaL, 0xbe0b1010L,
-    0xc90c2086L, 0x5768b525L, 0x206f85b3L, 0xb966d409L, 0xce61e49fL,
-    0x5edef90eL, 0x29d9c998L, 0xb0d09822L, 0xc7d7a8b4L, 0x59b33d17L,
-    0x2eb40d81L, 0xb7bd5c3bL, 0xc0ba6cadL, 0xedb88320L, 0x9abfb3b6L,
-    0x03b6e20cL, 0x74b1d29aL, 0xead54739L, 0x9dd277afL, 0x04db2615L,
-    0x73dc1683L, 0xe3630b12L, 0x94643b84L, 0x0d6d6a3eL, 0x7a6a5aa8L,
-    0xe40ecf0bL, 0x9309ff9dL, 0x0a00ae27L, 0x7d079eb1L, 0xf00f9344L,
-    0x8708a3d2L, 0x1e01f268L, 0x6906c2feL, 0xf762575dL, 0x806567cbL,
-    0x196c3671L, 0x6e6b06e7L, 0xfed41b76L, 0x89d32be0L, 0x10da7a5aL,
-    0x67dd4accL, 0xf9b9df6fL, 0x8ebeeff9L, 0x17b7be43L, 0x60b08ed5L,
-    0xd6d6a3e8L, 0xa1d1937eL, 0x38d8c2c4L, 0x4fdff252L, 0xd1bb67f1L,
-    0xa6bc5767L, 0x3fb506ddL, 0x48b2364bL, 0xd80d2bdaL, 0xaf0a1b4cL,
-    0x36034af6L, 0x41047a60L, 0xdf60efc3L, 0xa867df55L, 0x316e8eefL,
-    0x4669be79L, 0xcb61b38cL, 0xbc66831aL, 0x256fd2a0L, 0x5268e236L,
-    0xcc0c7795L, 0xbb0b4703L, 0x220216b9L, 0x5505262fL, 0xc5ba3bbeL,
-    0xb2bd0b28L, 0x2bb45a92L, 0x5cb36a04L, 0xc2d7ffa7L, 0xb5d0cf31L,
-    0x2cd99e8bL, 0x5bdeae1dL, 0x9b64c2b0L, 0xec63f226L, 0x756aa39cL,
-    0x026d930aL, 0x9c0906a9L, 0xeb0e363fL, 0x72076785L, 0x05005713L,
-    0x95bf4a82L, 0xe2b87a14L, 0x7bb12baeL, 0x0cb61b38L, 0x92d28e9bL,
-    0xe5d5be0dL, 0x7cdcefb7L, 0x0bdbdf21L, 0x86d3d2d4L, 0xf1d4e242L,
-    0x68ddb3f8L, 0x1fda836eL, 0x81be16cdL, 0xf6b9265bL, 0x6fb077e1L,
-    0x18b74777L, 0x88085ae6L, 0xff0f6a70L, 0x66063bcaL, 0x11010b5cL,
-    0x8f659effL, 0xf862ae69L, 0x616bffd3L, 0x166ccf45L, 0xa00ae278L,
-    0xd70dd2eeL, 0x4e048354L, 0x3903b3c2L, 0xa7672661L, 0xd06016f7L,
-    0x4969474dL, 0x3e6e77dbL, 0xaed16a4aL, 0xd9d65adcL, 0x40df0b66L,
-    0x37d83bf0L, 0xa9bcae53L, 0xdebb9ec5L, 0x47b2cf7fL, 0x30b5ffe9L,
-    0xbdbdf21cL, 0xcabac28aL, 0x53b39330L, 0x24b4a3a6L, 0xbad03605L,
-    0xcdd70693L, 0x54de5729L, 0x23d967bfL, 0xb3667a2eL, 0xc4614ab8L,
-    0x5d681b02L, 0x2a6f2b94L, 0xb40bbe37L, 0xc30c8ea1L, 0x5a05df1bL,
-    0x2d02ef8dL
+    0x00000000, 0x77073096, 0xee0e612c, 0x990951ba, 0x076dc419,
+    0x706af48f, 0xe963a535, 0x9e6495a3, 0x0edb8832, 0x79dcb8a4,
+    0xe0d5e91e, 0x97d2d988, 0x09b64c2b, 0x7eb17cbd, 0xe7b82d07,
+    0x90bf1d91, 0x1db71064, 0x6ab020f2, 0xf3b97148, 0x84be41de,
+    0x1adad47d, 0x6ddde4eb, 0xf4d4b551, 0x83d385c7, 0x136c9856,
+    0x646ba8c0, 0xfd62f97a, 0x8a65c9ec, 0x14015c4f, 0x63066cd9,
+    0xfa0f3d63, 0x8d080df5, 0x3b6e20c8, 0x4c69105e, 0xd56041e4,
+    0xa2677172, 0x3c03e4d1, 0x4b04d447, 0xd20d85fd, 0xa50ab56b,
+    0x35b5a8fa, 0x42b2986c, 0xdbbbc9d6, 0xacbcf940, 0x32d86ce3,
+    0x45df5c75, 0xdcd60dcf, 0xabd13d59, 0x26d930ac, 0x51de003a,
+    0xc8d75180, 0xbfd06116, 0x21b4f4b5, 0x56b3c423, 0xcfba9599,
+    0xb8bda50f, 0x2802b89e, 0x5f058808, 0xc60cd9b2, 0xb10be924,
+    0x2f6f7c87, 0x58684c11, 0xc1611dab, 0xb6662d3d, 0x76dc4190,
+    0x01db7106, 0x98d220bc, 0xefd5102a, 0x71b18589, 0x06b6b51f,
+    0x9fbfe4a5, 0xe8b8d433, 0x7807c9a2, 0x0f00f934, 0x9609a88e,
+    0xe10e9818, 0x7f6a0dbb, 0x086d3d2d, 0x91646c97, 0xe6635c01,
+    0x6b6b51f4, 0x1c6c6162, 0x856530d8, 0xf262004e, 0x6c0695ed,
+    0x1b01a57b, 0x8208f4c1, 0xf50fc457, 0x65b0d9c6, 0x12b7e950,
+    0x8bbeb8ea, 0xfcb9887c, 0x62dd1ddf, 0x15da2d49, 0x8cd37cf3,
+    0xfbd44c65, 0x4db26158, 0x3ab551ce, 0xa3bc0074, 0xd4bb30e2,
+    0x4adfa541, 0x3dd895d7, 0xa4d1c46d, 0xd3d6f4fb, 0x4369e96a,
+    0x346ed9fc, 0xad678846, 0xda60b8d0, 0x44042d73, 0x33031de5,
+    0xaa0a4c5f, 0xdd0d7cc9, 0x5005713c, 0x270241aa, 0xbe0b1010,
+    0xc90c2086, 0x5768b525, 0x206f85b3, 0xb966d409, 0xce61e49f,
+    0x5edef90e, 0x29d9c998, 0xb0d09822, 0xc7d7a8b4, 0x59b33d17,
+    0x2eb40d81, 0xb7bd5c3b, 0xc0ba6cad, 0xedb88320, 0x9abfb3b6,
+    0x03b6e20c, 0x74b1d29a, 0xead54739, 0x9dd277af, 0x04db2615,
+    0x73dc1683, 0xe3630b12, 0x94643b84, 0x0d6d6a3e, 0x7a6a5aa8,
+    0xe40ecf0b, 0x9309ff9d, 0x0a00ae27, 0x7d079eb1, 0xf00f9344,
+    0x8708a3d2, 0x1e01f268, 0x6906c2fe, 0xf762575d, 0x806567cb,
+    0x196c3671, 0x6e6b06e7, 0xfed41b76, 0x89d32be0, 0x10da7a5a,
+    0x67dd4acc, 0xf9b9df6f, 0x8ebeeff9, 0x17b7be43, 0x60b08ed5,
+    0xd6d6a3e8, 0xa1d1937e, 0x38d8c2c4, 0x4fdff252, 0xd1bb67f1,
+    0xa6bc5767, 0x3fb506dd, 0x48b2364b, 0xd80d2bda, 0xaf0a1b4c,
+    0x36034af6, 0x41047a60, 0xdf60efc3, 0xa867df55, 0x316e8eef,
+    0x4669be79, 0xcb61b38c, 0xbc66831a, 0x256fd2a0, 0x5268e236,
+    0xcc0c7795, 0xbb0b4703, 0x220216b9, 0x5505262f, 0xc5ba3bbe,
+    0xb2bd0b28, 0x2bb45a92, 0x5cb36a04, 0xc2d7ffa7, 0xb5d0cf31,
+    0x2cd99e8b, 0x5bdeae1d, 0x9b64c2b0, 0xec63f226, 0x756aa39c,
+    0x026d930a, 0x9c0906a9, 0xeb0e363f, 0x72076785, 0x05005713,
+    0x95bf4a82, 0xe2b87a14, 0x7bb12bae, 0x0cb61b38, 0x92d28e9b,
+    0xe5d5be0d, 0x7cdcefb7, 0x0bdbdf21, 0x86d3d2d4, 0xf1d4e242,
+    0x68ddb3f8, 0x1fda836e, 0x81be16cd, 0xf6b9265b, 0x6fb077e1,
+    0x18b74777, 0x88085ae6, 0xff0f6a70, 0x66063bca, 0x11010b5c,
+    0x8f659eff, 0xf862ae69, 0x616bffd3, 0x166ccf45, 0xa00ae278,
+    0xd70dd2ee, 0x4e048354, 0x3903b3c2, 0xa7672661, 0xd06016f7,
+    0x4969474d, 0x3e6e77db, 0xaed16a4a, 0xd9d65adc, 0x40df0b66,
+    0x37d83bf0, 0xa9bcae53, 0xdebb9ec5, 0x47b2cf7f, 0x30b5ffe9,
+    0xbdbdf21c, 0xcabac28a, 0x53b39330, 0x24b4a3a6, 0xbad03605,
+    0xcdd70693, 0x54de5729, 0x23d967bf, 0xb3667a2e, 0xc4614ab8,
+    0x5d681b02, 0x2a6f2b94, 0xb40bbe37, 0xc30c8ea1, 0x5a05df1b,
+    0x2d02ef8d
 ]
 
 def crc32(s, crc=0):
     result = 0
-    crc = ~long(crc) & 0xffffffffL
+    crc = ~int(crc) & 0xffffffff
     for c in s:
-        crc = crc_32_tab[(crc ^ c) & 0xffL] ^ (crc >> 8)
+        crc = crc_32_tab[(crc ^ c) & 0xff] ^ (crc >> 8)
         #/* Note:  (crc >> 8) MUST zero fill on left
 
-    result = crc ^ 0xffffffffL
+    result = crc ^ 0xffffffff
     
     if result > 2**31:
         result = ((result + 2**31) % 2**32) - 2**31
diff --git a/pypy/module/imp/importing.py b/pypy/module/imp/importing.py
--- a/pypy/module/imp/importing.py
+++ b/pypy/module/imp/importing.py
@@ -34,6 +34,8 @@
 DEFAULT_SOABI = 'pypy-%d%d' % PYPY_VERSION[:2]
 CHECK_FOR_PYW = sys.platform == 'win32'
 
+PYC_TAG = 'pypy-%d%d' % PYPY_VERSION[:2]
+
 @specialize.memo()
 def get_so_extension(space):
     if space.config.objspace.soabi is not None:
@@ -91,10 +93,7 @@
 else:
     # XXX that's slow
     def case_ok(filename):
-        index = filename.rfind(os.sep)
-        if os.altsep is not None:
-            index2 = filename.rfind(os.altsep)
-            index = max(index, index2)
+        index = rightmost_sep(filename)
         if index < 0:
             directory = os.curdir
         else:
@@ -862,17 +861,63 @@
                       space.wrap(space.builtin))
     code_w.exec_code(space, w_dict, w_dict)
 
+def rightmost_sep(filename):
+    "Like filename.rfind('/'), but also search for \\."
+    index = filename.rfind(os.sep)
+    if os.altsep is not None:
+        index2 = filename.rfind(os.altsep)
+        index = max(index, index2)
+    return index
+
 def make_compiled_pathname(pathname):
     "Given the path to a .py file, return the path to its .pyc file."
-    return pathname + 'c'
+    # foo.py -> __pycache__/foo.<tag>.pyc
+
+    lastpos = rightmost_sep(pathname) + 1
+    assert lastpos >= 0  # zero when slash, takes the full name
+    fname = pathname[lastpos:]
+    if lastpos > 0:
+        # Windows: re-use the last separator character (/ or \\) when
+        # appending the __pycache__ path.
+        lastsep = pathname[lastpos-1]
+    else:
+        lastsep = os.sep
+    ext = fname
+    for i in range(len(fname)):
+        if fname[i] == '.':
+            ext = fname[:i + 1]
+    
+    result = (pathname[:lastpos] + "__pycache__" + lastsep +
+              ext + PYC_TAG + '.pyc')
+    return result
 
 def make_source_pathname(pathname):
-    pos_extension = len(pathname) - 4  # len('.pyc')
-    if pos_extension < 0:
-        raise ValueError("path is too short")
-    if pathname[pos_extension:] != '.pyc':
-        raise ValueError("not a .pyc path name")
-    return pathname[:pos_extension + 3]
+    "Given the path to a .pyc file, return the path to its .py file."
+    # (...)/__pycache__/foo.<tag>.pyc -> (...)/foo.py
+
+    right = rightmost_sep(pathname)
+    if right < 0:
+        raise ValueError()
+    left = rightmost_sep(pathname[:right]) + 1
+    assert left >= 0
+    if pathname[left:right] != '__pycache__':
+        raise ValueError()
+
+    # Now verify that the path component to the right of the last
+    # slash has two dots in it.
+    rightpart = pathname[right + 1:]
+    dot0 = rightpart.find('.') + 1
+    if dot0 <= 0:
+        raise ValueError
+    dot1 = rightpart[dot0:].find('.') + 1
+    if dot1 <= 0:
+        raise ValueError
+    # Too many dots?
+    if rightpart[dot0 + dot1:].find('.') >= 0:
+        raise ValueError
+
+    result = pathname[:left] + rightpart[:dot0] + 'py'
+    return result
 
 @jit.dont_look_inside
 def load_source_module(space, w_modulename, w_mod, pathname, source,
@@ -1027,6 +1072,17 @@
     Errors are ignored, if a write error occurs an attempt is made to
     remove the file.
     """
+    # Ensure that the __pycache__ directory exists
+    dirsep = rightmost_sep(cpathname)
+    if dirsep < 0:
+        return
+    dirname = cpathname[:dirsep]
+    mode = src_mode | 0333  # +wx
+    try:
+        os.mkdir(dirname, mode)
+    except OSError:
+        pass
+
     w_marshal = space.getbuiltinmodule('marshal')
     try:
         w_bytes = space.call_method(w_marshal, 'dumps', space.wrap(co),
diff --git a/pypy/module/termios/interp_termios.py b/pypy/module/termios/interp_termios.py
--- a/pypy/module/termios/interp_termios.py
+++ b/pypy/module/termios/interp_termios.py
@@ -24,15 +24,11 @@
     fd = space.c_filedescriptor_w(w_fd)
     w_iflag, w_oflag, w_cflag, w_lflag, w_ispeed, w_ospeed, w_cc = \
              space.unpackiterable(w_attributes, expected_length=7)
-    w_builtin = space.getbuiltinmodule('__builtin__')
     cc = []
     for w_c in space.unpackiterable(w_cc):
         if space.is_true(space.isinstance(w_c, space.w_int)):
-            ch = space.call_function(space.getattr(w_builtin,
-                                          space.wrap('chr')), w_c)
-            cc.append(space.str_w(ch))
-        else:
-            cc.append(space.str_w(w_c))
+            w_c = space.call(space.w_bytes, space.newlist([w_c]))
+        cc.append(space.bytes_w(w_c))
     tup = (space.int_w(w_iflag), space.int_w(w_oflag),
            space.int_w(w_cflag), space.int_w(w_lflag),
            space.int_w(w_ispeed), space.int_w(w_ospeed), cc)
diff --git a/pypy/module/termios/test/test_termios.py b/pypy/module/termios/test/test_termios.py
--- a/pypy/module/termios/test/test_termios.py
+++ b/pypy/module/termios/test/test_termios.py
@@ -23,7 +23,7 @@
 
     def _spawn(self, *args, **kwds):
         print 'SPAWN:', args, kwds
-        child = self.pexpect.spawn(*args, **kwds)
+        child = self.pexpect.spawn(timeout=600, *args, **kwds)
         child.logfile = sys.stdout
         return child
 
@@ -53,7 +53,7 @@
         termios.tcdrain(2)
         termios.tcflush(2, termios.TCIOFLUSH)
         termios.tcflow(2, termios.TCOON)
-        print 'ok!'
+        print('ok!')
         """)
         f = udir.join("test_tcall.py")
         f.write(source)
@@ -65,7 +65,7 @@
         import sys
         import termios
         termios.tcsetattr(sys.stdin, 1, [16640, 4, 191, 2608, 15, 15, ['\x03', '\x1c', '\x7f', '\x15', '\x04', 0, 1, '\x00', '\x11', '\x13', '\x1a', '\x00', '\x12', '\x0f', '\x17', '\x16', '\x00', '\x00', '\x00', '\x00', '\x00', '\x00', '\x00', '\x00', '\x00', '\x00', '\x00', '\x00', '\x00', '\x00', '\x00', '\x00']])
-        print 'ok!'
+        print('ok!')
         """)
         f = udir.join("test_tcsetattr.py")
         f.write(source)
@@ -76,9 +76,9 @@
         source = py.code.Source("""
         import termios
         import fcntl
-        lgt = len(fcntl.ioctl(2, termios.TIOCGWINSZ, '\000'*8))
+        lgt = len(fcntl.ioctl(2, termios.TIOCGWINSZ, b'\000'*8))
         assert lgt == 8
-        print 'ok!'
+        print('ok!')
         """)
         f = udir.join("test_ioctl_termios.py")
         f.write(source)
@@ -97,7 +97,7 @@
         assert len([i for i in f[-1] if isinstance(i, int)]) == 2
         assert isinstance(f[-1][termios.VMIN], int)
         assert isinstance(f[-1][termios.VTIME], int)
-        print 'ok!'
+        print('ok!')
         """)
         f = udir.join("test_ioctl_termios.py")
         f.write(source)
diff --git a/pypy/objspace/fake/objspace.py b/pypy/objspace/fake/objspace.py
--- a/pypy/objspace/fake/objspace.py
+++ b/pypy/objspace/fake/objspace.py
@@ -157,6 +157,10 @@
         "NOT_RPYTHON"
         raise NotImplementedError
 
+    def wrapbytes(self, x):
+        assert isinstance(x, str)
+        return w_some_obj()
+
     def _see_interp2app(self, interp2app):
         "NOT_RPYTHON"
         activation = interp2app._code.activation
@@ -278,7 +282,7 @@
     for name in (ObjSpace.ConstantTable +
                  ObjSpace.ExceptionTable +
                  ['int', 'str', 'float', 'long', 'tuple', 'list',
-                  'dict', 'unicode', 'complex', 'slice', 'bool',
+                  'dict', 'bytes', 'complex', 'slice', 'bool',
                   'type', 'text', 'object']):
         setattr(FakeObjSpace, 'w_' + name, w_some_obj())
     #
diff --git a/pypy/objspace/std/longtype.py b/pypy/objspace/std/longtype.py
--- a/pypy/objspace/std/longtype.py
+++ b/pypy/objspace/std/longtype.py
@@ -40,6 +40,7 @@
                 w_obj = space.int(w_obj)
             else:
                 w_obj = space.trunc(w_obj)
+                w_obj = space.int(w_obj)
             return w_obj
     else:
         base = space.int_w(w_base)


More information about the pypy-commit mailing list
diff --git a/pypy/module/imp/test/test_import.py b/pypy/module/imp/test/test_import.py
--- a/pypy/module/imp/test/test_import.py
+++ b/pypy/module/imp/test/test_import.py
@@ -38,7 +38,7 @@
                     test_reload = "def test():\n    raise ValueError\n",
                     infinite_reload = "import infinite_reload; reload(infinite_reload)",
                     del_sys_module = "import sys\ndel sys.modules['del_sys_module']\n",
-                    itertools = "hello_world = 42\n",
+                    queue = "hello_world = 42\n",
                     gc = "should_never_be_seen = 42\n",
                     )
     root.ensure("notapackage", dir=1)    # empty, no __init__.py
@@ -75,7 +75,7 @@
              )
     setuppkg("pkg_substituting",
              __init__ = "import sys, pkg_substituted\n"
-                        "print 'TOTO', __name__\n"
+                        "print('TOTO', __name__)\n"
                         "sys.modules[__name__] = pkg_substituted")
     setuppkg("pkg_substituted", mod='')
     setuppkg("evil_pkg",
@@ -102,6 +102,7 @@
         w = space.wrap
         w_modname = w("compiled.x")
         filename = str(p.join("x.py"))
+        pycname = importing.make_compiled_pathname("x.py")
         stream = streamio.open_file_as_stream(filename, "r")
         try:
             importing.load_source_module(space,
@@ -113,7 +114,7 @@
             stream.close()
         if space.config.objspace.usepycfiles:
             # also create a lone .pyc file
-            p.join('lone.pyc').write(p.join('x.pyc').read(mode='rb'),
+            p.join('lone.pyc').write(p.join(pycname).read(mode='rb'),
                                      mode='wb')
 
     # create a .pyw file
@@ -150,7 +151,7 @@
 class AppTestImport:
 
     def setup_class(cls): # interpreter-level
-        cls.space = gettestobjspace(usemodules=['itertools'])
+        #cls.space = gettestobjspace(usemodules=['itertools'])
         cls.w_runappdirect = cls.space.wrap(conftest.option.runappdirect)
         cls.saved_modules = _setup(cls.space)
         #XXX Compile class
@@ -159,6 +160,9 @@
     def teardown_class(cls): # interpreter-level
         _teardown(cls.space, cls.saved_modules)
 
+    def w_exec_(self, cmd, ns):
+        exec(cmd, ns)
+
     def test_set_sys_modules_during_import(self):
         from evil_pkg import evil
         assert evil.a == 42
@@ -373,7 +377,7 @@
 
     def test_invalid__name__(self):
         glob = {}
-        exec "__name__ = None; import sys" in glob
+        exec("__name__ = None; import sys", glob)
         import sys
         assert glob['sys'] is sys
 
@@ -418,16 +422,18 @@
         assert pkg.pkg1.__package__ == 'pkg.pkg1'
 
     def test_future_relative_import_error_when_in_non_package(self):
-        exec """def imp():
+        ns = {}
+        exec("""def imp():
                     from .string import inpackage
-        """.rstrip()
-        raises(ValueError, imp)
+        """.rstrip(), ns)
+        raises(ValueError, ns['imp'])
 
     def test_future_relative_import_error_when_in_non_package2(self):
-        exec """def imp():
+        ns = {}
+        exec("""def imp():
                     from .. import inpackage
-        """.rstrip()
-        raises(ValueError, imp)
+        """.rstrip(), ns)
+        raises(ValueError, ns['imp'])
 
     def test_relative_import_with___name__(self):
         import sys
@@ -456,9 +462,9 @@
     def test__package__(self):
         # Regression test for http://bugs.python.org/issue3221.
         def check_absolute():
-            exec "from os import path" in ns
+            self.exec_("from os import path", ns)
         def check_relative():
-            exec "from . import a" in ns
+            self.exec_("from . import a", ns)
 
         # Check both OK with __package__ and __name__ correct
         ns = dict(__package__='pkg', __name__='pkg.notarealmodule')
@@ -578,8 +584,11 @@
 
     def test_cache_from_source(self):
         import imp
-        assert imp.cache_from_source('a/b/c.py') == 'a/b/c.pyc'
-        assert imp.source_from_cache('a/b/c.pyc') == 'a/b/c.py'
+        pycfile = imp.cache_from_source('a/b/c.py')
+        assert pycfile.startswith('a/b/__pycache__/c.pypy-')
+        assert pycfile.endswith('.pyc')
+        assert imp.source_from_cache('a/b/__pycache__/c.pypy-17.pyc'
+                                     ) == 'a/b/c.py'
         raises(ValueError, imp.source_from_cache, 'a/b/c.py')
 
     def test_shadow_builtin(self):
@@ -596,34 +605,32 @@
 
     def test_shadow_extension_1(self):
         if self.runappdirect: skip("hard to test: module is already imported")
         # 'import itertools' is supposed to find itertools.py if there is
         # one in sys.path.
         import sys
-        assert 'itertools' not in sys.modules
-        import itertools
-        assert hasattr(itertools, 'hello_world')
-        assert not hasattr(itertools, 'count')
-        assert '(built-in)' not in repr(itertools)
-        del sys.modules['itertools']
+        assert 'queue' not in sys.modules
+        import queue
+        assert hasattr(queue, 'hello_world')
+        assert not hasattr(queue, 'count')
+        assert '(built-in)' not in repr(queue)
+        del sys.modules['queue']
 
     def test_shadow_extension_2(self):
         if self.runappdirect: skip("hard to test: module is already imported")
         # 'import itertools' is supposed to find the built-in module even
         # if there is also one in sys.path as long as it is *after* the
-        # special entry '.../lib_pypy/__extensions__'.  (Note that for now
-        # there is one in lib_pypy/itertools.py, which should not be seen
-        # either; hence the (built-in) test below.)
+        # special entry '.../lib_pypy/__extensions__'.
         import sys
-        assert 'itertools' not in sys.modules
+        assert 'queue' not in sys.modules
         sys.path.append(sys.path.pop(0))
         try:
-            import itertools
-            assert not hasattr(itertools, 'hello_world')
-            assert hasattr(itertools, 'izip')
-            assert '(built-in)' in repr(itertools)
+            import queue
+            assert not hasattr(queue, 'hello_world')
+            assert hasattr(queue, 'izip')
+            assert '(built-in)' in repr(queue)
         finally:
             sys.path.insert(0, sys.path.pop())
-        del sys.modules['itertools']
+        del sys.modules['queue']
 
 
 class TestAbi:
@@ -885,7 +892,7 @@
         stream.close()
 
         # And the .pyc has been generated
-        cpathname = udir.join('test.pyc')
+        cpathname = udir.join(importing.make_compiled_pathname('test.py'))
         assert cpathname.check()
 
     def test_write_compiled_module(self):
@@ -979,7 +986,7 @@
         py.test.skip("unresolved issues with win32 shell quoting rules")
     from pypy.interpreter.test.test_zpy import pypypath 
     extrapath = udir.ensure("pythonpath", dir=1) 
-    extrapath.join("urllib.py").write("print 42\n")
+    extrapath.join("urllib.py").write("print(42)\n")
     old = os.environ.get('PYTHONPATH', None)
     oldlang = os.environ.pop('LANG', None)
     try: 
@@ -1024,7 +1031,7 @@
                 if fullname in self.namestoblock:
                     return self
             def load_module(self, fullname):
-                raise ImportError, "blocked"
+                raise ImportError("blocked")
 
         import sys, imp
         modname = "errno" # an arbitrary harmless builtin module
@@ -1094,7 +1101,7 @@
                     path = [self.path]
                 try:
                     file, filename, stuff = imp.find_module(subname, path)
-                except ImportError, e:
+                except ImportError:
                     return None
                 return ImpLoader(file, filename, stuff)
 
@@ -1139,8 +1146,8 @@
 
     def test_run_compiled_module(self):
         # XXX minimal test only
-        import imp, new
-        module = new.module('foobar')
+        import imp, types
+        module = types.ModuleType('foobar')
         raises(IOError, imp._run_compiled_module,
                'foobar', 'this_file_does_not_exist', None, module)
 
@@ -1161,14 +1168,14 @@
         # a mostly-empty zip file
         path = os.path.join(self.udir, 'test_getimporter.zip')
         f = open(path, 'wb')
-        f.write('PK\x03\x04\n\x00\x00\x00\x00\x00P\x9eN>\x00\x00\x00\x00\x00'
-                '\x00\x00\x00\x00\x00\x00\x00\x05\x00\x15\x00emptyUT\t\x00'
-                '\x03wyYMwyYMUx\x04\x00\xf4\x01d\x00PK\x01\x02\x17\x03\n\x00'
-                '\x00\x00\x00\x00P\x9eN>\x00\x00\x00\x00\x00\x00\x00\x00\x00'
-                '\x00\x00\x00\x05\x00\r\x00\x00\x00\x00\x00\x00\x00\x00\x00'
-                '\xa4\x81\x00\x00\x00\x00emptyUT\x05\x00\x03wyYMUx\x00\x00PK'
-                '\x05\x06\x00\x00\x00\x00\x01\x00\x01\x00@\x00\x00\x008\x00'
-                '\x00\x00\x00\x00')
+        f.write(b'PK\x03\x04\n\x00\x00\x00\x00\x00P\x9eN>\x00\x00\x00\x00\x00'
+                b'\x00\x00\x00\x00\x00\x00\x00\x05\x00\x15\x00emptyUT\t\x00'
+                b'\x03wyYMwyYMUx\x04\x00\xf4\x01d\x00PK\x01\x02\x17\x03\n\x00'
+                b'\x00\x00\x00\x00P\x9eN>\x00\x00\x00\x00\x00\x00\x00\x00\x00'
+                b'\x00\x00\x00\x05\x00\r\x00\x00\x00\x00\x00\x00\x00\x00\x00'
+                b'\xa4\x81\x00\x00\x00\x00emptyUT\x05\x00\x03wyYMUx\x00\x00PK'
+                b'\x05\x06\x00\x00\x00\x00\x01\x00\x01\x00@\x00\x00\x008\x00'
+                b'\x00\x00\x00\x00')
         f.close()
         importer = imp._getimporter(path)
         import zipimport
@@ -1193,16 +1200,16 @@
     def test_import_possibly_from_pyc(self):
         from compiled import x
         if self.usepycfiles:
-            assert x.__file__.endswith('x.pyc')
+            assert x.__file__.endswith('.pyc')
         else:
-            assert x.__file__.endswith('x.py')
+            assert x.__file__.endswith('.py')
         try:
             from compiled import lone
         except ImportError:
             assert not self.lonepycfiles, "should have found 'lone.pyc'"
         else:
             assert self.lonepycfiles, "should not have found 'lone.pyc'"
-            assert lone.__file__.endswith('lone.pyc')
+            assert lone.__file__.endswith('.pyc')
 
 class AppTestNoLonePycFile(AppTestNoPycFile):
     spaceconfig = {
@@ -596,34 +605,32 @@
     def test_shadow_extension_1(self):
         if self.runappdirect: skip("hard to test: module is already imported")
-        # 'import itertools' is supposed to find itertools.py if there is
+        # 'import queue' is supposed to find queue.py if there is
         # one in sys.path.
         import sys
@@ -596,34 +605,32 @@
     def test_shadow_extension_2(self):
         if self.runappdirect: skip("hard to test: module is already imported")
-        # 'import itertools' is supposed to find the built-in module even
+        # 'import queue' is supposed to find the built-in module even
         # if there is also one in sys.path as long as it is *after* the